/* SPDX-License-Identifier: Zlib */

#ifndef ZATHURA_VERSION_H
#define ZATHURA_VERSION_H

#define ZATHURA_VERSION_MAJOR 0
#define ZATHURA_VERSION_MINOR 5
#define ZATHURA_VERSION_REV 11
#define ZATHURA_VERSION "0.5.11"
#define ZATHURA_API_VERSION 6
#define ZATHURA_ABI_VERSION 7

#endif
